@@ -35,15 +35,16 @@ do {
 };
 
 use OP::Class qw| true false |;
+use OP::Num;
 use Perl6::Subs;
 use Scalar::Util qw| blessed |;
 
 use base qw| Time::Piece::Nonpolluting OP::Array |;
 
-use overload (
+use overload
+  %OP::Num::overload,
   '""'  => '_sprint',
-  '<=>' => '_compare',
-);
+  '<=>' => '_compare';
 
 method assert(OP::Class $class: *@rules) {
   my %parsed = OP::Type::__parseTypeArgs(
@@ -130,11 +131,11 @@ __END__
 
 =head1 NAME
 
-OP::DateTime
+OP::DateTime - Overloaded Time object class
 
 =head1 VERSION
 
-  $Id: //depotit/tools/snitchd/OP-0.20/lib/OP/DateTime.pm#1 $
+  $Id: //depotit/tools/source/snitchd-0.20/lib/OP/DateTime.pm#15 $
 
 =head1 SYNOPSIS
 
