@@ -26,7 +26,7 @@ use Hash::Util;
 
 =head1 NAME
 
-OP::Hash
+OP::Hash - Hashtable object
 
 =head1 DESCRIPTION
 
@@ -300,7 +300,7 @@ This file is part of L<OP>.
 
 =head1 REVISION
 
-$Id: //depotit/tools/snitchd/OP-0.20/lib/OP/Hash.pm#1 $
+$Id: //depotit/tools/source/snitchd-0.20/lib/OP/Hash.pm#13 $
 
 =cut
 
