@@ -12,7 +12,7 @@
 
 =head1 NAME
 
-OP::Log
+OP::Log - Circular message sink wrapper
 
 =head1 DESCRIPTION
 
@@ -311,6 +311,6 @@ This file is part of L<OP>.
 
 =head1 REVISION
 
-$Id: //depotit/tools/snitchd/OP-0.20/lib/OP/Log.pm#1 $
+$Id: //depotit/tools/source/snitchd-0.20/lib/OP/Log.pm#7 $
 
 =cut
