@@ -60,7 +60,7 @@ __END__
 
 =head1 NAME
 
-OP::TimeSpan
+OP::TimeSpan - Time range object class
 
 =head1 VERSION
 
@@ -74,8 +74,6 @@ OP::TimeSpan
 
 =head1 DESCRIPTION
 
-Time range object. Represents a number of seconds.
-
 Extends L<OP::Object>, L<Time::Seconds>.
 
 Stringifies as number of seconds unless overridden.
