@@ -14,11 +14,7 @@ package OP::Utility;
 
 =head1 NAME
 
-OP::Utility
-
-=head1 DESCRIPTION
-
-System functions required globally by OP
+OP::Utility - System functions required globally by OP
 
 =head1 SYNOPSIS
 
@@ -613,7 +609,7 @@ This file is part of L<OP>.
 
 =head1 REVISON
 
-$Id: //depotit/tools/snitchd/OP-0.20/lib/OP/Utility.pm#1 $
+$Id: //depotit/tools/source/snitchd-0.20/lib/OP/Utility.pm#7 $
 
 =cut
 
